translate.convert.po2php.rephp

Package translate :: Package convert :: Module po2php :: Class rephp |
[hide private]
[frames] | no frames]

# Class rephp

source code

Instance Methods | [hide private]
__init__(self, templatefile) | source code
convertstore(self, inputstore, includefuzzy=False) | source code
makestoredict(self, store, includefuzzy=False) make a dictionary of the translations | source code
convertline(self, line) | source code